__title__ = 'ssaw'
__version__ = '0.1.1'
__description__ = 'Survey Solutions API Wrapper'
__url__ = 'https://github.com/vavalomi/ssaw'
__author__ = 'Zurab Sajaia'
__author_email__ = 'vavalomi@hotmail.com'
